@@ -17,7 +17,7 @@ limitations under the License.
 package snippet
 
 import (
-	extensions "k8s.io/api/extensions/v1beta1"
+	networking "k8s.io/api/networking/v1"
 
 	"github.com/open-cluster-management/management-ingress/pkg/ingress/annotations/parser"
 	"github.com/open-cluster-management/management-ingress/pkg/ingress/resolver"
@@ -35,6 +35,6 @@ func NewParser(r resolver.Resolver) parser.IngressAnnotation {
 // Parse parses the annotations contained in the ingress rule
 // used to indicate if the location/s contains a fragment of
 // configuration to be included inside the paths of the rules
-func (a snippet) Parse(ing *extensions.Ingress) (interface{}, error) {
+func (a snippet) Parse(ing *networking.Ingress) (interface{}, error) {
 	return parser.GetStringAnnotation("configuration-snippet", ing)
 }
